Credits
=======

Development Lead
----------------

-   Lincoln Harris <[@lincoln-harris](https://github.com/lincoln-harris)> &lt;ljharris018@gmail.com&gt;

Contributors
------------

-   Olga Botvinnik <[@olgabot](https://github.com/olgabot)>
-   Rohan Vanheusden <[@rvanheusden](https://github.com/rvanheusden)>
